vfbLib.parsers.base.EncodedValueParser
======================================

.. currentmodule:: vfbLib.parsers.base

.. autoclass:: EncodedValueParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~EncodedValueParser.__init__
      ~EncodedValueParser.parse
      ~EncodedValueParser.parse_hex
      ~EncodedValueParser.read_double
      ~EncodedValueParser.read_doubles
      ~EncodedValueParser.read_float
      ~EncodedValueParser.read_floats
      ~EncodedValueParser.read_int16
      ~EncodedValueParser.read_int32
      ~EncodedValueParser.read_int8
      ~EncodedValueParser.read_str
      ~EncodedValueParser.read_str_all
      ~EncodedValueParser.read_uint16
      ~EncodedValueParser.read_uint32
      ~EncodedValueParser.read_uint8
      ~EncodedValueParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~EncodedValueParser.encoding
      ~EncodedValueParser.master_count
      ~EncodedValueParser.stream
      ~EncodedValueParser.ttStemsH_count
      ~EncodedValueParser.ttStemsV_count
   
   